/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.tdengine.config;

import org.apache.seatunnel.api.configuration.Option;
import org.apache.seatunnel.api.configuration.Options;

import lombok.AllArgsConstructor;
import lombok.Data;

import java.util.List;

@Data
@AllArgsConstructor
public class TDengineSinkOptions extends TDengineCommonOptions {

    public static final Option<String> TIMEZONE =
            Options.key("timezone")
                    .stringType()
                    .defaultValue("UTC")
                    .withDescription("The timezone used for timestamp conversion, default is UTC");

    public static final Option<List<String>> WRITE_COLUMNS =
            Options.key("write_columns")
                    .listType()
                    .noDefaultValue()
                    .withDescription(
                            "The field names to be written to TDengine "
                                    + "If not specified, all fields will be written. "
                                    + "This option is useful when the source schema does not match the TDengine table schema.");
}
